summaryrefslogtreecommitdiffstats
path: root/webkit/tools/test_shell/webwidget_host.h
diff options
context:
space:
mode:
authoragl@chromium.org <agl@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-12-11 21:50:41 +0000
committeragl@chromium.org <agl@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-12-11 21:50:41 +0000
commit5590f8286b568b29e67f0d575dad0cb84f071e87 (patch)
tree76a5cc4ce0cdb148a3a4d258104e1f249878bc91 /webkit/tools/test_shell/webwidget_host.h
parent35a61135047d83c9b87fdb57f86367c05efeeb26 (diff)
downloadchromium_src-5590f8286b568b29e67f0d575dad0cb84f071e87.zip
chromium_src-5590f8286b568b29e67f0d575dad0cb84f071e87.tar.gz
chromium_src-5590f8286b568b29e67f0d575dad0cb84f071e87.tar.bz2
Rename ViewHandle to NativeView et al.
ViewHandle is a very unfortunate name when we actually start dealing with views, so we are renaming the cross-platform typedefs to make it clear that they refer to platform specific native UI elements. Review URL: http://codereview.chromium.org/13754 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@6826 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'webkit/tools/test_shell/webwidget_host.h')
-rw-r--r--webkit/tools/test_shell/webwidget_host.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/webkit/tools/test_shell/webwidget_host.h b/webkit/tools/test_shell/webwidget_host.h
index cb6c3f1..0b4e197 100644
--- a/webkit/tools/test_shell/webwidget_host.h
+++ b/webkit/tools/test_shell/webwidget_host.h
@@ -18,21 +18,21 @@ namespace gfx {
class Size;
}
// This class is a simple ViewHandle-based host for a WebWidget
class WebWidgetHost {
public:
// The new instance is deleted once the associated ViewHandle is destroyed.
// The newly created window should be resized after it is created, using the
// MoveWindow (or equivalent) function.
- static WebWidgetHost* Create(gfx::WindowHandle parent_window,
+ static WebWidgetHost* Create(gfx::NativeWindow parent_window,
WebWidgetDelegate* delegate);
- static WebWidgetHost* FromWindow(gfx::WindowHandle view);
+ static WebWidgetHost* FromWindow(gfx::NativeWindow view);
#if defined(OS_MACOSX)
- static void HandleEvent(gfx::WindowHandle window, NSEvent *event);
+ static void HandleEvent(gfx::NativeWindow window, NSEvent *event);
#endif
- gfx::ViewHandle view_handle() const { return view_; }
+ gfx::NativeView view_handle() const { return view_; }
WebWidget* webwidget() const { return webwidget_; }
void DidInvalidateRect(const gfx::Rect& rect);
@@ -83,7 +83,7 @@ class WebWidgetHost {
// parent: a GtkBox to pack the new widget at the end of
// host: a pointer to a WebWidgetHost (or subclass thereof)
// ---------------------------------------------------------------------------
- static gfx::WindowHandle CreateWindow(gfx::WindowHandle parent, void* host);
+ static gfx::NativeWindow CreateWindow(gfx::NativeWindow parent, void* host);
void WindowDestroyed();
void Resize(const gfx::Size& size);
#endif
@@ -98,7 +98,7 @@ class WebWidgetHost {
#endif
}
- gfx::ViewHandle view_;
+ gfx::NativeView view_;
WebWidget* webwidget_;
scoped_ptr<gfx::PlatformCanvas> canvas_;
@@ -18,21 +18,21 @@ namespace gfx {
class Size;
}
-// This class is a simple ViewHandle-based host for a WebWidget
+// This class is a simple NativeView-based host for a WebWidget
class WebWidgetHost {
public:
@@ -18,21 +18,21 @@ namespace gfx {
class WebWidgetHost {
public:
- // The new instance is deleted once the associated ViewHandle is destroyed.
+ // The new instance is deleted once the associated NativeView is destroyed.
// The newly created window should be resized after it is created, using the
// MoveWindow (or equivalent) function.